/* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
/*

    Copyright (C) 2012-2015  Dieter Schärf <ds@dschaerf.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.

 */

const Lang = imports.lang;

const ExtensionUtils = imports.misc.extensionUtils;

const ExtensionSystem = imports.ui.extensionSystem;
const Main = imports.ui.main;

const Extension = ExtensionUtils.getCurrentExtension();

const Convenience = Extension.imports.convenience;

/*
    PanelManager - DroopDownArrow
 */
const KEY_SHOW_DROPDOWN_ARROW = 'show-dropdown-arrow';

const DropDownArrow = new Lang.Class({
    Name: 'DropDownArrow',

    _init: function() {
        this._settings = Convenience.getSettings(Convenience.CURRENT_SETTINGS_SCHEMA);
        this._connectExtensionSystem = ExtensionSystem.connect('extension-state-changed', Lang.bind(this, this._onShowDropDownArrow));
        this._connectSettings = this._settings.connect('changed::'+KEY_SHOW_DROPDOWN_ARROW, Lang.bind(this, this._onShowDropDownArrow));
        this._onShowDropDownArrow();
    },

    _onShowDropDownArrow: function() {
        this._updateVisibility(this._settings.get_boolean(KEY_SHOW_DROPDOWN_ARROW));
    },

    _setDropDownArrowVisible: function(actor, visible) {
        if (actor.text === '\u25BE' || 
            (actor.has_style_class_name && actor.has_style_class_name('popup-menu-arrow'))) {
            actor.visible = visible;
        } else if (actor.get_children) {
            let children = actor.get_children();
            for each(let child in children) {
                this._setDropDownArrowVisible(child, visible);
            }
        }
    },

    _updateVisibility: function(visible) {
        for each(let indicator in Main.panel.statusArea) {
            if (indicator.actor) this._setDropDownArrowVisible(indicator.actor, visible);
        }
    },

    destroy: function() {
        this._settings.disconnect(this._connectSettings);
        ExtensionSystem.disconnect(this._connectExtensionSystem);
        this._updateVisibility(true);
    }
});

function getExtension() {
    return Convenience.checkGSV(3, 10) || Convenience.checkGSV(3, 12) || Convenience.checkGSV(3, 14) || Convenience.checkGSV(3, 16) || Convenience.checkGSV(3, 18) ? new DropDownArrow() : null;
}
